@@ -72,6 +72,10 @@ sub gst_service_sysv_get_paths
        "mandriva-2006.1" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
        "mandriva-2007.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
        "mandriva-2007.1" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+       "mandriva-2008.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+       "mandriva-2008.1" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+       "mandriva-2009.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+       "mandriva-2009.1" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
 
        "blackpanther-4.0" => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
 
@@ -152,6 +156,10 @@ sub gst_service_sysv_get_runlevels
        "mandriva-2006.1" => [3, 5],
        "mandriva-2007.0" => [3, 5],
        "mandriva-2007.1" => [3, 5],
+       "mandriva-2008.0" => [3, 5],
+       "mandriva-2008.1" => [3, 5],
+       "mandriva-2009.0" => [3, 5],
+       "mandriva-2009.1" => [3, 5],
 
        "blackpanther-4.0" => [3, 5],
 
@@ -234,6 +242,8 @@ sub gst_service_get_runlevel_roles
      "mandriva-2007.1" => "redhat-5.2",
      "mandriva-2008.0" => "redhat-5.2",
      "mandriva-2008.1" => "redhat-5.2",
+     "mandriva-2009.0" => "redhat-5.2",
+     "mandriva-2009.1" => "redhat-5.2",
      
      "blackpanther-4.0" => "redhat-5.2",
 
